@@ -1,7 +1,7 @@
 /*
  *
  * 
- * Copyright (C) 2008 Benjamin Scott   <benscott@nwlink.com>
+ * Copyright (C) 2008, 2011 Benjamin Scott   <benscott@nwlink.com>
  *
  * This file is part of the Kvpm project.
  *
@@ -11,11 +11,13 @@
  * 
  * See the file "COPYING" for the exact licensing terms.
  */
+
+
 #ifndef DEVICEPROPERTIESSTACK_H
 #define DEVICEPROPERTIESSTACK_H
 
 #include <QList>
-#include <QModelIndex>
+#include <QTreeWidgetItem>
 #include <QStackedWidget>
 #include <QStringList>
 
@@ -28,11 +30,15 @@ Q_OBJECT
 
     QStringList m_device_path_list;  // full path of each device on the stack, in the same order
 
+    QWidget *getDefaultWidget();
+
  public:
-     DevicePropertiesStack(QList<StorageDevice *> Devices, QWidget *parent = 0);
+     explicit DevicePropertiesStack(QWidget *parent = 0);
+     void loadData(QList<StorageDevice *> devices);
 
  public slots:
-     void changeDeviceStackIndex(QModelIndex Index);
+     void changeDeviceStackIndex(QTreeWidgetItem *item);
 };
 
 #endif
+
