@@ -1,7 +1,7 @@
 /*
  *
  * 
- * Copyright (C) 2008 Benjamin Scott   <benscott@nwlink.com>
+ * Copyright (C) 2008, 2011 Benjamin Scott   <benscott@nwlink.com>
  *
  * This file is part of the Kvpm project.
  *
@@ -11,36 +11,37 @@
  * 
  * See the file "COPYING" for the exact licensing terms.
  */
+
 #ifndef STORAGEDEVICESIZECHART_H
 #define STORAGEDEVICESIZECHART_H
 
-#include <QAbstractItemModel>
-#include <QList>
-#include <QLabel>
 #include <QFrame>
+#include <QList>
+#include <QTreeWidget>
+#include <QTreeWidgetItem>
 #include <QHBoxLayout>
 
-#include "devicemodel.h"
-#include "devicesizechartseg.h"
+class DeviceTree;
+
 
 class DeviceSizeChart : public QFrame
 {
     Q_OBJECT
 
-    QHBoxLayout *layout;
-    QHBoxLayout *extended_layout;        // The layout for chart segments inside an extented partition
+    QHBoxLayout *m_layout;
+    QHBoxLayout *m_extended_layout;        // The layout for chart segments inside an extended partition
+    QTreeWidget *m_tree;
 
-    QList<QWidget *> segments, extended_segments;    // Segments of the bar chart, not the disk.
-    QList<double> ratios, extended_ratios;
+    QList<QWidget *> m_segments, m_extended_segments;    // Segments of the bar chart, not the disk.
+    QList<double>    m_ratios,   m_extended_ratios;
     
-    StorageDeviceModel *device_model;
 
 public:
-    DeviceSizeChart(StorageDeviceModel *model, QWidget *parent);
+    DeviceSizeChart(QWidget *parent);
     void resizeEvent(QResizeEvent *event);
     
 public slots:
-     void setNewDevice(QModelIndex index);
+     void setNewDevice(QTreeWidgetItem *deviceItem);
 };
 
 #endif
