@@ -1,7 +1,7 @@
 /*
  *
  * 
- * Copyright (C) 2008 Benjamin Scott   <benscott@nwlink.com>
+ * Copyright (C) 2008, 2010, 2011 Benjamin Scott   <benscott@nwlink.com>
  *
  * This file is part of the Kvpm project.
  *
@@ -15,41 +15,27 @@
 #ifndef STORAGEDEVICESIZECHARTSEG_H
 #define STORAGEDEVICESIZECHARTSEG_H
 
-class StoragePartition;
-class StorageDeviceItem;
 
-
-#include <QMenu>
+#include <QTreeWidgetItem>
 #include <QFrame>
+#include <QMenu>
+
+
+class StoragePartition;
 
 
 class DeviceChartSeg : public QFrame
 {
 Q_OBJECT
 
-    StorageDeviceItem *m_item;
-
-    QString m_pv_name;
-    
+    QTreeWidgetItem *m_item;
     StoragePartition *m_partition;
 
 public:
-    DeviceChartSeg(StorageDeviceItem *storageDeviceItem, QWidget *parent = 0);
+    explicit DeviceChartSeg(QTreeWidgetItem *storageItem, QWidget *parent = 0);
 
 public slots:
     void popupContextMenu(QPoint point);
-    void addPartition();
-    void mkfsPartition();
-    void mountPartition();
-    void pvcreatePartition();
-    void pvremovePartition();
-    void removePartition();
-    void removefsPartition();
-    void moveresizePartition();
-    void vgcreatePartition();
-    void vgreducePartition();
-    void vgextendPartition(QAction *action);
-    void unmountPartition();
 
 };
 	
