@@ -1,7 +1,7 @@
 /*
  *
  * 
- * Copyright (C) 2008, 2009 Benjamin Scott   <benscott@nwlink.com>
+ * Copyright (C) 2008, 2009, 2010, 2011 Benjamin Scott   <benscott@nwlink.com>
  *
  * This file is part of the kvpm project.
  *
@@ -20,25 +20,26 @@
 #include <QWidget>
 #include <QSplitter>
 #include <QScrollArea>
+#include <QVBoxLayout>
 					
+class DeviceTree;
+class DevicePropertiesStack;
+class DeviceSizeChart;
 class StorageDevice;
-class StorageDeviceModel;
-class MasterList;
-class DeviceTreeView;
 
 class DeviceTab : public QWidget
 {
-    QList<StorageDevice *> m_devs;
-    DeviceTreeView *m_tree;
-    StorageDeviceModel *m_model;
+    QVBoxLayout *m_layout;
+    DeviceTree  *m_tree;
+    QSplitter   *m_tree_properties_splitter;
+    DeviceSizeChart *m_size_chart;
+    DevicePropertiesStack *m_device_stack;
 
-    QScrollArea *setupPropertyWidgets();
-
-    void setHiddenColumns();
+    QScrollArea *setupPropertyStack();
 
  public:
-    DeviceTab(QList<StorageDevice *> Devices, QWidget *parent = 0);
-
+    DeviceTab(QWidget *parent = 0);
+    void rescan( QList<StorageDevice *> Devices );
 };
 
 
