@@ -1,7 +1,7 @@
 /*
  *
  * 
- * Copyright (C) 2008, 2009 Benjamin Scott   <benscott@nwlink.com>
+ * Copyright (C) 2008, 2009, 2011 Benjamin Scott   <benscott@nwlink.com>
  *
  * This file is part of the kvpm project.
  *
@@ -23,19 +23,21 @@
 
 class ExecutableFinder : public QObject
 {
+Q_OBJECT
 
     QStringList m_default_search_paths;
     QStringList m_keys;                       // Names of the executables we are looking for
     QStringList m_not_found;                  // The ones we didn't find
-    QMap<QString, QString> m_path_map;
+    static QMap<QString, QString> m_path_map;
     
  public:
     ExecutableFinder(QObject *parent = 0);
-    QString getExecutablePath(QString name);
+    static QString getPath(QString name);
+    void reload();                            // rescan the system for needed executables
+    void reload(QStringList search);          // As above using the stringlist for the search paths
     QStringList getAllPaths();
     QStringList getAllNames();
     QStringList getNotFound();
-    void reload();                            // rescan the system for needed executables
 };
 
 #endif
