@@ -12,31 +12,28 @@
  * See the file "COPYING" for the exact licensing terms.
  */
 
+#include "fsblocksize.h"
+
 #include <KLocale>
 #include <KMessageBox>
 
 #include <QtGui>
 
-#include "fsblocksize.h"
 #include "processprogress.h"
 
 
 long get_fs_block_size(QString path){
 
-    QStringList arguments, 
-                output,
-                temp_stringlist;
-
+    QStringList arguments;
     QString block_string;
 
     arguments << "dumpe2fs" 
               << "-h" 
               << path;
 
-    ProcessProgress blocksize_scan(arguments, i18n("Checking blocksize") );
-    output = blocksize_scan.programOutput();
-
-    temp_stringlist << output.filter("Block size", Qt::CaseInsensitive);
+    ProcessProgress blocksize_scan(arguments);
+    const QStringList output = blocksize_scan.programOutput();
+    const QStringList temp_stringlist = output.filter("Block size", Qt::CaseInsensitive);
 
     if( temp_stringlist.size() ){
         block_string = temp_stringlist[0];
