@@ -1,7 +1,7 @@
 /*
  *
  * 
- * Copyright (C) 2008 Benjamin Scott   <benscott@nwlink.com>
+ * Copyright (C) 2008, 2011, 2012 Benjamin Scott   <benscott@nwlink.com>
  *
  * This file is part of the Kvpm project.
  *
@@ -21,9 +21,9 @@
 #include <KDoubleValidator>
 
 class LogVol;
+class SizeSelectorBox;
 class VolGroup;
 
-bool lv_reduce(LogVol *logicalVolume);
 
 
 class LVReduceDialog : public KDialog
@@ -32,24 +32,16 @@ Q_OBJECT
 
     LogVol   *m_lv;
     VolGroup *m_vg;
-
-    KDoubleValidator *m_size_validator;
-    KComboBox *m_size_combo;
-    KLineEdit *m_size_edit;
- 
-    int m_size_combo_last_index;
-    long long m_current_lv_size;
-    long long m_min_lv_size;
-
-    long long getSizeEditExtents(int index);
+    SizeSelectorBox *m_size_selector;
+    bool m_bailout;
 
  public:
-    LVReduceDialog(LogVol *logicalVolume, QWidget *parent = 0);
+    explicit LVReduceDialog(LogVol *const volume, QWidget *parent = 0);
+    bool bailout();
      
  private slots:
-    void sizeComboAdjust(int index);
-    void validateInput(QString text);
     void doShrink();
+    void resetOkButton();
  
 };
 
