@@ -1,7 +1,7 @@
 /*
  *
  * 
- * Copyright (C) 2008 Benjamin Scott   <benscott@nwlink.com>
+ * Copyright (C) 2008, 2010, 2011 Benjamin Scott   <benscott@nwlink.com>
  *
  * This file is part of the Kvpm project.
  *
@@ -12,34 +12,35 @@
  * See the file "COPYING" for the exact licensing terms.
  */
 
-#ifndef LVNAME_H
-#define LVNAME_H
+#ifndef LVRENAME_H
+#define LVRENAME_H
 
 #include <KDialog>
 #include <KLineEdit>
-
 #include <QStringList>
+#include <QRegExpValidator>
 
 class LogVol;
 
-bool rename_lv(LogVol *logicalVolume);
 
 class LVRenameDialog : public KDialog
 {
 Q_OBJECT
 
-    QString m_old_name;
-    QString m_vg_name;
+    LogVol  *m_lv;
+    QString  m_old_name;
+    QString  m_vg_name;
     KLineEdit *m_new_name;
     QRegExpValidator *m_name_validator;
 
+    QString getNewMapperPath();
+
 public:
-    LVRenameDialog(LogVol *logicalVolume, QWidget *parent = 0);
-    QStringList arguments();
+    explicit LVRenameDialog(LogVol *const volume, QWidget *parent = 0);
 
 private slots:
-    void validateName(QString);
-    void renameMountEntries();
+    void validateName(QString name);
+    void commitChanges();
 
 };
 
