@@ -1,7 +1,7 @@
 /*
  *
  * 
- * Copyright (C) 2008 Benjamin Scott   <benscott@nwlink.com>
+ * Copyright (C) 2008, 2010 Benjamin Scott   <benscott@nwlink.com>
  *
  * This file is part of the Kvpm project.
  *
@@ -34,23 +34,10 @@ Q_OBJECT
      KMenu *m_context_menu;
      
  public:
-     LVChartSeg(VolGroup *volumeGroup, LogVol *logicalVolume, QString use, QWidget *parent);
+     LVChartSeg(VolGroup *const group, LogVol *const volume, const QString use, QWidget *parent);
 
  private slots:
      void popupContextMenu(QPoint);
-     void extendLogicalVolume();
-     void createLogicalVolume();
-     void changeLogicalVolume();
-     void reduceLogicalVolume();
-     void removeLogicalVolume();
-     void renameLogicalVolume();
-     void addMirror();
-     void removeMirror();
-     void createSnapshot();
-     void mkfsLogicalVolume();
-     void movePhysicalExtents();
-     void mountFilesystem();
-     void unmountFilesystem();
 
 };
 
