@@ -1,7 +1,7 @@
 /*
  *
  * 
- * Copyright (C) 2008 Benjamin Scott   <benscott@nwlink.com>
+ * Copyright (C) 2008, 2010, 2011 Benjamin Scott   <benscott@nwlink.com>
  *
  * This file is part of the kvpm project.
  *
@@ -12,8 +12,10 @@
  * See the file "COPYING" for the exact licensing terms.
  */
 
+#include "mount.h"
 
 #include <sys/mount.h>
+#include <linux/fs.h>
 #include <errno.h>
 #include <string.h>
 
@@ -23,35 +25,59 @@
 #include <KMessageBox>
 #include <KUrl>
 #include <KLocale>
+
 #include <QtGui>
 
 #include "logvol.h"
-#include "mount.h"
 #include "mountentry.h"
+#include "mounttables.h"
 #include "storagepartition.h"
 
 
 const int BUFF_LEN = 2000;   // Enough?
 
 
-MountDialog::MountDialog(QString deviceToMount, QString filesystemType, QWidget *parent) : 
-KDialog(parent),
-m_device_to_mount(deviceToMount),
-m_filesystem_type(filesystemType)
+MountDialog::MountDialog(LogVol *const volume, QWidget *parent) : KDialog(parent)
 {
+    m_device_to_mount = volume->getMapperPath();
+    m_filesystem_type = volume->getFilesystem();
+    m_is_writable = volume->isWritable();
+    m_mount_point = volume->getFstabMountPoint();
 
-    KTabWidget *dialog_body = new KTabWidget(this);
+    buildDialog();
+}
+
+MountDialog::MountDialog(StoragePartition *const partition, QWidget *parent) : KDialog(parent)
+{
+    m_device_to_mount = partition->getName();
+    m_filesystem_type = partition->getFilesystem();
+    m_is_writable = partition->isWritable();
+    m_mount_point = partition->getFstabMountPoint();
+
+    buildDialog();
+}
+
+void MountDialog::buildDialog()
+{
+    setCaption("Mount a Filesystem");
+    QWidget *const dialog_body = new QWidget(this);
     setMainWidget(dialog_body);
 
-    QWidget *main_tab    = new QWidget(this);
-    QVBoxLayout *main_layout = new QVBoxLayout();
-    main_tab->setLayout(main_layout);
-    
-    main_layout->addWidget( filesystemBox() );
-    main_layout->addWidget( mountPointBox() );
+    QVBoxLayout *const layout = new QVBoxLayout();
+    dialog_body->setLayout(layout);
 
-    dialog_body->addTab(main_tab,     i18n("Main") );
-    dialog_body->addTab(optionsTab(), i18n("Options") );
+    QLabel *const device_label = new QLabel( "<b>" + i18n("Device To Mount: ") + m_device_to_mount + "</b>");
+    device_label->setAlignment(Qt::AlignCenter);    
+    layout->addWidget(device_label);
+
+    QHBoxLayout *const main_layout = new QHBoxLayout();
+    layout->addLayout(main_layout);
+    QVBoxLayout *const left_layout = new QVBoxLayout();
+    main_layout->addLayout(left_layout);
+
+    left_layout->addWidget( filesystemBox() );
+    left_layout->addWidget( mountPointBox() );
+    main_layout->addWidget( optionsBox() );
 
     connect(this, SIGNAL( accepted() ), 
 	    this, SLOT( mountFilesystem() ));
@@ -59,13 +85,13 @@ m_filesystem_type(filesystemType)
 
 QWidget* MountDialog::filesystemBox()
 {
-    QGroupBox   *filesystem_box = new QGroupBox( i18n("Filesystem type"), this);
-    QVBoxLayout *layout_left    = new QVBoxLayout();
-    QVBoxLayout *layout_center  = new QVBoxLayout();
-    QVBoxLayout *layout_right   = new QVBoxLayout();
-    QHBoxLayout *upper_layout   = new QHBoxLayout();
-    QHBoxLayout *lower_layout   = new QHBoxLayout();
-    QVBoxLayout *filesystem_layout   = new QVBoxLayout();
+    QGroupBox   *const filesystem_box = new QGroupBox( i18n("Filesystem Type"), this);
+    QVBoxLayout *const layout_left    = new QVBoxLayout();
+    QVBoxLayout *const layout_center  = new QVBoxLayout();
+    QVBoxLayout *const layout_right   = new QVBoxLayout();
+    QHBoxLayout *const upper_layout   = new QHBoxLayout();
+    QHBoxLayout *const lower_layout   = new QHBoxLayout();
+    QVBoxLayout *const filesystem_layout = new QVBoxLayout();
     upper_layout->addLayout(layout_left);
     upper_layout->addLayout(layout_center);
     upper_layout->addLayout(layout_right);
@@ -73,19 +99,21 @@ QWidget* MountDialog::filesystemBox()
     filesystem_layout->addLayout(lower_layout);
     filesystem_box->setLayout(filesystem_layout);
     
-    ext2_button      = new QRadioButton("Ext2", this);
-    ext3_button      = new QRadioButton("Ext3", this);
-    ext4_button      = new QRadioButton("Ext4", this);
-    reiserfs3_button = new QRadioButton("Reiserfs Ver. 3", this);
-    reiserfs4_button = new QRadioButton("Reiserfs Ver. 4", this);
-    xfs_button       = new QRadioButton("Xfs", this);
-    jfs_button       = new QRadioButton("Jfs", this);
-    vfat_button      = new QRadioButton("vfat", this);
+    ext2_button      = new QRadioButton("ext2", this);
+    ext3_button      = new QRadioButton("ext3", this);
+    ext4_button      = new QRadioButton("ext4", this);
+    btrfs_button     = new QRadioButton("btrfs",this);
+    reiserfs3_button = new QRadioButton("reiser3", this);
+    reiserfs4_button = new QRadioButton("reiser4", this);
+    xfs_button       = new QRadioButton("xfs", this);
+    jfs_button       = new QRadioButton("jfs", this);
+    vfat_button      = new QRadioButton("vfat",this);
     udf_button       = new QRadioButton("udf", this);
     iso9660_button   = new QRadioButton("iso9660", this);
     hfs_button       = new QRadioButton("hfs", this);
+    ntfs_button      = new QRadioButton("ntfs", this);
     
-    specify_button   = new QRadioButton( i18n("Specify other:"), this);
+    specify_button   = new QRadioButton( i18n("Specify another fileystem:"), this);
 
     if( m_filesystem_type == "ext2" )
 	ext2_button->setChecked(true);
@@ -93,6 +121,8 @@ QWidget* MountDialog::filesystemBox()
 	ext3_button->setChecked(true);
     else if( m_filesystem_type == "ext4" )
 	ext4_button->setChecked(true);
+    else if( m_filesystem_type == "btrfs" )
+	btrfs_button->setChecked(true);
     else if( m_filesystem_type == "reiserfs" )
 	reiserfs3_button->setChecked(true);
     else if( m_filesystem_type == "reiser4" )
@@ -109,26 +139,33 @@ QWidget* MountDialog::filesystemBox()
 	iso9660_button->setChecked(true);
     else if( m_filesystem_type == "hfs" )
 	hfs_button->setChecked(true);
+    else if( m_filesystem_type == "ntfs" )
+	ntfs_button->setChecked(true);
     else
 	specify_button->setChecked(true);
 
     m_filesystem_edit = new KLineEdit(m_filesystem_type);
 
-    if( specify_button->isChecked() && m_filesystem_edit->text() == "" )
+    if( specify_button->isChecked() && (m_filesystem_edit->text()).isEmpty() )
 	(button(KDialog::Ok))->setEnabled(false);
     
     layout_left->addWidget(ext2_button);
     layout_left->addWidget(ext3_button);
     layout_left->addWidget(ext4_button);
-    layout_left->addWidget(vfat_button);
+    layout_left->addWidget(btrfs_button);
+    layout_left->addWidget(ntfs_button);
+    layout_left->addStretch();
     layout_center->addWidget(reiserfs3_button);
     layout_center->addWidget(reiserfs4_button);
     layout_center->addWidget(xfs_button);
     layout_center->addWidget(jfs_button);
+    layout_center->addStretch();
     layout_right->addWidget(udf_button);
     layout_right->addWidget(iso9660_button);
     layout_right->addWidget(hfs_button);
-    
+    layout_right->addWidget(vfat_button);
+    layout_right->addStretch();    
+
     lower_layout->addWidget(specify_button);
     lower_layout->addWidget(m_filesystem_edit);
 
@@ -141,24 +178,22 @@ QWidget* MountDialog::filesystemBox()
     return filesystem_box;
 }
 
-QWidget* MountDialog::optionsTab()
+QWidget* MountDialog::optionsBox()
 {
-
-    QWidget *options_tab = new QWidget();
+    QWidget *options_box = new QGroupBox( i18n("Mount Options") );
     QVBoxLayout *options_layout = new QVBoxLayout();
-    options_tab->setLayout(options_layout);
+    options_box->setLayout(options_layout);
     
-    QGroupBox *common_options_box = new QGroupBox( i18n("Common mount options"), this);
+    QGroupBox *common_options_box = new QGroupBox( i18n("Common Options"), this);
     QVBoxLayout *layout_left      = new QVBoxLayout();
     QVBoxLayout *layout_right     = new QVBoxLayout();
-    QHBoxLayout *common_options_layout   = new QHBoxLayout();
+    QHBoxLayout *common_options_layout = new QHBoxLayout();
     common_options_layout->addLayout(layout_left);
     common_options_layout->addLayout(layout_right);
     common_options_box->setLayout(common_options_layout);
 
     sync_check     = new QCheckBox("sync");
     dirsync_check  = new QCheckBox("dirsync");
-    dirsync_check->setEnabled(false);
     rw_check       = new QCheckBox("rw");
     suid_check     = new QCheckBox("suid");
     dev_check      = new QCheckBox("dev");
@@ -167,7 +202,13 @@ QWidget* MountDialog::optionsTab()
     acl_check      = new QCheckBox("acl");
     user_xattr_check = new QCheckBox("user xattr");
     
-    rw_check->setChecked(true);
+    if(m_is_writable)
+        rw_check->setChecked(true);
+    else{
+        rw_check->setChecked(false);
+        rw_check->setEnabled(false);
+    }
+
     suid_check->setChecked(true);
     dev_check->setChecked(true);
     exec_check->setChecked(true);
@@ -194,11 +235,15 @@ QWidget* MountDialog::optionsTab()
     
     QHBoxLayout *options_atime_layout = new QHBoxLayout();
     options_layout->addLayout(options_atime_layout);
+
     QGroupBox *atime_box = new QGroupBox( i18n("Update atime"), this);
     QVBoxLayout *atime_layout = new QVBoxLayout();
     atime_box->setLayout(atime_layout);
     options_atime_layout->addWidget(common_options_box);
 
+    QVBoxLayout *atime_journal_layout = new QVBoxLayout();
+    options_atime_layout->addLayout(atime_journal_layout);
+
     m_filesystem_journal_box = new QGroupBox( i18n("Journaling") );
     QVBoxLayout *journaling_layout = new QVBoxLayout;
     m_filesystem_journal_box->setLayout(journaling_layout);
@@ -209,14 +254,13 @@ QWidget* MountDialog::optionsTab()
     journaling_layout->addWidget(data_journal_button);
     journaling_layout->addWidget(data_ordered_button);
     journaling_layout->addWidget(data_writeback_button);
-    options_atime_layout->addWidget(m_filesystem_journal_box);
+    atime_journal_layout->addWidget(m_filesystem_journal_box);
 
     atime_button      = new QRadioButton("atime");
-    atime_button->setChecked(true);
     noatime_button    = new QRadioButton("noatime");
     nodiratime_button = new QRadioButton("nodiratime");
     relatime_button   = new QRadioButton("relatime");
-    relatime_button->setEnabled(false);
+    relatime_button->setChecked(true);
     atime_layout->addWidget(atime_button);
     atime_layout->addWidget(noatime_button);
     atime_layout->addWidget(nodiratime_button);
@@ -229,18 +273,17 @@ QWidget* MountDialog::optionsTab()
 				      "access time was earlier than the current modify "
 				      "or change time") );
     
-    options_atime_layout->addWidget(atime_box);
+    atime_journal_layout->addWidget(atime_box);
+
+    QGroupBox *filesystem_options_box = new QGroupBox( i18n("Filesystem specific mount options") );
+    m_fs_specific_edit = new KLineEdit();
+    m_fs_specific_edit->setPlaceholderText( i18n("comma separated list of additional mount options") );
 
-    QGroupBox *filesystem_options_box = new QGroupBox( i18n("Filesystem specific  mount options") );
-    m_filesystem_edit = new KLineEdit();
-    QLabel *additional_options_label = new QLabel( i18n("comma separated list of additional mount options") );
-    
     options_layout->addWidget(filesystem_options_box);
     QVBoxLayout *filesystem_options_box_layout = new QVBoxLayout();
     
     filesystem_options_box->setLayout(filesystem_options_box_layout);
-    filesystem_options_box_layout->addWidget(additional_options_label);
-    filesystem_options_box_layout->addWidget(m_filesystem_edit);
+    filesystem_options_box_layout->addWidget(m_fs_specific_edit);
 
     toggleAdditionalOptions(true);
 
@@ -250,34 +293,59 @@ QWidget* MountDialog::optionsTab()
     connect(ext3_button, SIGNAL( toggled(bool) ),
 	    this, SLOT( toggleAdditionalOptions(bool)));
     
+    connect(ext4_button, SIGNAL( toggled(bool) ),
+	    this, SLOT( toggleAdditionalOptions(bool)));
+    
     connect(reiserfs3_button, SIGNAL( toggled(bool) ),
 	    this, SLOT( toggleAdditionalOptions(bool)));
 
     connect(reiserfs4_button, SIGNAL( toggled(bool) ),
 	    this, SLOT( toggleAdditionalOptions(bool)));
     
-    return options_tab;
+    connect(btrfs_button, SIGNAL( toggled(bool) ),
+	    this, SLOT( toggleAdditionalOptions(bool)));
+    
+    connect(xfs_button, SIGNAL( toggled(bool) ),
+	    this, SLOT( toggleAdditionalOptions(bool)));
+
+    connect(jfs_button, SIGNAL( toggled(bool) ),
+	    this, SLOT( toggleAdditionalOptions(bool)));
+    
+    connect(vfat_button, SIGNAL( toggled(bool) ),
+	    this, SLOT( toggleAdditionalOptions(bool)));
+
+    connect(ntfs_button, SIGNAL( toggled(bool) ),
+	    this, SLOT( toggleAdditionalOptions(bool)));
+    
+    connect(specify_button, SIGNAL( toggled(bool) ),
+	    this, SLOT( toggleAdditionalOptions(bool)));
+    
+    connect(udf_button, SIGNAL( toggled(bool) ),
+	    this, SLOT( toggleAdditionalOptions(bool)));
+    
+    connect(iso9660_button, SIGNAL( toggled(bool) ),
+	    this, SLOT( toggleAdditionalOptions(bool)));
+    
+    connect(hfs_button, SIGNAL( toggled(bool) ),
+	    this, SLOT( toggleAdditionalOptions(bool)));
+    
+    return options_box;
 }
 
 QWidget* MountDialog::mountPointBox()
 {
-    if( hasFstabEntry(m_device_to_mount) )
-	m_mount_point = getFstabEntry(m_device_to_mount);
-    else
-	m_mount_point = "";
-
-    QGroupBox *mount_point_box = new QGroupBox( i18n("Mount point") );
-    QHBoxLayout *mount_point_layout = new QHBoxLayout();
+    QGroupBox *const mount_point_box = new QGroupBox( i18n("Mount Point") );
+    QHBoxLayout *const mount_point_layout = new QHBoxLayout();
     mount_point_box->setLayout(mount_point_layout);
     
     m_mount_point_edit = new KLineEdit(m_mount_point);
 
-    if( m_mount_point_edit->text() == "" )
+    if( (m_mount_point_edit->text()).isEmpty() )
     	(button(KDialog::Ok))->setEnabled(false);
 
     mount_point_layout->addWidget(m_mount_point_edit);
     
-    QPushButton *browse_button = new QPushButton( i18n("Browse"), this);
+    QPushButton *const browse_button = new QPushButton( i18n("Browse"), this);
     mount_point_layout->addWidget(browse_button);
 
     connect(m_mount_point_edit, SIGNAL( textChanged(const QString) ), 
@@ -291,30 +359,22 @@ QWidget* MountDialog::mountPointBox()
 
 void MountDialog::selectMountPoint(bool)
 {
-    char device[BUFF_LEN];
+    const QString filter = "*";
+    QString start;
 
-    strncpy(device, m_device_to_mount.toAscii().data(), BUFF_LEN);
+    if( !m_mount_point.isEmpty() )
+	start = QString("file://" + m_mount_point);
+    else
+	start = QString("file:///");
+
+    const KUrl url(start);
+    KFileDialog dialog( url, filter, 0 );
+    dialog.setModal(true);
+    dialog.setMode(KFile::Directory);
+    dialog.exec();
+    m_mount_point = dialog.selectedFile();
     
-    if(m_mount_point != ""){
-	const KUrl url( "file://" + QString(m_mount_point) );
-	const QString filter = "*";
-	KFileDialog dialog( url, filter, 0 );
-	dialog.setModal(true);
-	dialog.setMode(KFile::Directory);
-	dialog.exec();
-	m_mount_point = dialog.selectedFile();
-    }
-    else{
-	const KUrl url( "file:///" );
-	const QString filter = "*";
-	KFileDialog dialog( url, filter, 0 );
-	dialog.setModal(true);
-	dialog.setMode(KFile::Directory);
-	dialog.exec();
-	m_mount_point = dialog.selectedFile();
-    }
-    
-    if( m_mount_point.length() > 1 && m_mount_point.endsWith("/") )
+    if( m_mount_point.length() > 1 && m_mount_point.endsWith('/') )
 	m_mount_point.chop(1);                           // remove trailing "/" character
 
     m_mount_point_edit->setText(m_mount_point);
@@ -332,6 +392,8 @@ void MountDialog::mountFilesystem()
 	m_filesystem_type = "ext3";
     else if( ext4_button->isChecked() )
 	m_filesystem_type = "ext4";
+    else if( btrfs_button->isChecked() )
+	m_filesystem_type = "btrfs";
     else if( reiserfs3_button->isChecked() )
 	m_filesystem_type = "reiserfs";
     else if( reiserfs4_button->isChecked() )
@@ -342,22 +404,24 @@ void MountDialog::mountFilesystem()
 	m_filesystem_type = "jfs";
     else if( vfat_button->isChecked() )
 	m_filesystem_type = "vfat";
+    else if( ntfs_button->isChecked() )
+	m_filesystem_type = "ntfs";
     else
 	m_filesystem_type = m_filesystem_edit->text();
 
     m_mount_point = m_mount_point_edit->text();
 
-    if( m_mount_point.length() > 1 && m_mount_point.endsWith("/") )  // remove trailing slash
+    if( m_mount_point.length() > 1 && m_mount_point.endsWith('/') )  // remove trailing slash
 	m_mount_point.chop(1);
 
     if( sync_check->isChecked() ){
 	standard_options.append("sync");
 	options |= MS_SYNCHRONOUS;
     }
-//    if( dirsync_check->isChecked() ){
-//	standard_options.append("dirsync");
-//	options |= MS_DIRSYNC;
-//  }
+    if( dirsync_check->isChecked() ){
+	standard_options.append("dirsync");
+	options |= MS_DIRSYNC;
+    }
     if( rw_check->isChecked() ){
 	standard_options.append("rw");
     }
@@ -383,7 +447,11 @@ void MountDialog::mountFilesystem()
 	options |= MS_MANDLOCK;
     }
 
-    if( noatime_button->isChecked() ){
+    if( atime_button->isChecked() ){
+	standard_options.append("atime");
+	options |= MS_STRICTATIME;
+    }
+    else if( noatime_button->isChecked() ){
 	standard_options.append("noatime");
 	options |= MS_NOATIME;
     }
@@ -391,10 +459,10 @@ void MountDialog::mountFilesystem()
 	standard_options.append("nodiratime");
 	options |= MS_NODIRATIME;
     }
-//    else if( relatime_button->isChecked() ){
-//	standard_options.append("nodiratime");
-//	options |= MS_RELATIME;
-//  }
+    else if( relatime_button->isChecked() ){
+	standard_options.append("relatime");
+	options |= MS_RELATIME;
+    }
 
 /* "data=ordered" is the default so we ignore that button */
 
@@ -405,14 +473,22 @@ void MountDialog::mountFilesystem()
 	    additional_options.append("data=writeback");
     }
 
-    if( acl_check->isChecked() )
-	additional_options.append("data=journal");
+    if( acl_check->isEnabled() ){
+        if( acl_check->isChecked() )
+            additional_options.append("acl");
+        else
+            additional_options.append("noacl");
+    }
 
-    if( user_xattr_check->isChecked() )
-	additional_options.append("user_xattr");
+    if( user_xattr_check->isEnabled() ){
+        if( user_xattr_check->isChecked() )
+            additional_options.append("user_xattr");
+        else
+            additional_options.append("nouser_xattr");
+    }
 
-    if( m_filesystem_edit->text().trimmed() != "" )
-	additional_options.append( (m_filesystem_edit->text()).trimmed() );
+    if( !m_fs_specific_edit->text().trimmed().isEmpty() )
+	additional_options.append( (m_fs_specific_edit->text()).trimmed() );
     
     all_options = standard_options.join(",");
 
@@ -421,37 +497,35 @@ void MountDialog::mountFilesystem()
 	all_options.append( additional_options.join(",") );
     }
 
-    int error = mount( m_device_to_mount.toAscii().data(),
-		       m_mount_point.toAscii().data(),
-		       m_filesystem_type.toAscii().data(),
-		       options, 
-		       ( additional_options.join(",") ).toAscii().data() );
+    const QByteArray device      = m_device_to_mount.toLocal8Bit();
+    const QByteArray mount_point = m_mount_point.toLocal8Bit();
+    const QByteArray fs_type     = m_filesystem_type.toLocal8Bit();
+    const QByteArray fs_options  = additional_options.join(",").toLocal8Bit();
+
+    int error = mount( device.data(), mount_point.data(), fs_type.data(), options, fs_options.data() );
 
     if( !error )
-	addMountEntry( m_device_to_mount, m_mount_point, m_filesystem_type, all_options, 0, 0);
+        MountTables::addEntry(m_device_to_mount, m_mount_point, m_filesystem_type, all_options, 0, 0);
     else
 	KMessageBox::error(0, QString("Error number: %1  %2").arg(errno).arg(strerror(errno)));
+}
 
+void MountDialog::toggleOKButton()
+{
+    if ( (specify_button->isChecked() && (m_filesystem_edit->text()).isEmpty()) || (m_mount_point_edit->text()).isEmpty())
+    	(button(KDialog::Ok))->setEnabled(false);
+    else
+    	(button(KDialog::Ok))->setEnabled(true);
 }
 
 void MountDialog::toggleOKButton(const QString)
 {
-    if ( (specify_button->isChecked() && m_filesystem_edit->text() == "" ) ||
-	 m_mount_point_edit->text() == "")
-
-    	(button(KDialog::Ok))->setEnabled(false);
-    else
-    	(button(KDialog::Ok))->setEnabled(true);
+    toggleOKButton();
 }
 
 void MountDialog::toggleOKButton(bool)
 {
-    if ( (specify_button->isChecked() && m_filesystem_edit->text() == "" ) ||
-	 m_mount_point_edit->text() == "")
-
-    	(button(KDialog::Ok))->setEnabled(false);
-    else
-    	(button(KDialog::Ok))->setEnabled(true);
+    toggleOKButton();
 }
 
 void MountDialog::toggleAdditionalOptions(bool)
@@ -461,11 +535,13 @@ void MountDialog::toggleAdditionalOptions(bool)
     else
         m_filesystem_journal_box->setEnabled(false);
 
-    if( ext2_button->isChecked() || ext3_button->isChecked() || 
+    if( ext2_button->isChecked() || ext3_button->isChecked() || ext4_button->isChecked() || 
 	reiserfs3_button->isChecked() || reiserfs4_button->isChecked() ){
 
 	acl_check->setEnabled(true);
+	acl_check->setChecked(true);
 	user_xattr_check->setEnabled(true);
+	user_xattr_check->setChecked(true);
     }
     else{
 	acl_check->setEnabled(false);
@@ -475,31 +551,3 @@ void MountDialog::toggleAdditionalOptions(bool)
     }
 }
 
-bool mount_filesystem(LogVol *volumeToMount)
-{
-    const QString prefix = "/dev/mapper/";
-    const QString lv_name = volumeToMount->getName();
-    const QString vg_name = volumeToMount->getVolumeGroupName();
-
-    MountDialog dialog(prefix + vg_name + "-" + lv_name, volumeToMount->getFilesystem());
-    dialog.exec();
-
-    if (dialog.result() == QDialog::Accepted)
-	return true;
-    else
-	return false;
-}
-
-bool mount_filesystem(StoragePartition *partition)
-{
-    QString device = partition->getPartitionPath();
-    QString filesystem = partition->getFileSystem();
-    
-    MountDialog dialog(device, filesystem);
-    dialog.exec();
-
-    if (dialog.result() == QDialog::Accepted)
-	return true;
-    else
-	return false;
-}
