@@ -1,7 +1,7 @@
 /*
  *
  * 
- * Copyright (C) 2008 Benjamin Scott   <benscott@nwlink.com>
+ * Copyright (C) 2008, 2011 Benjamin Scott   <benscott@nwlink.com>
  *
  * This file is part of the Kvpm project.
  *
@@ -19,35 +19,32 @@
 #include <QStringList>
 #include <QEventLoop>
 #include <QProcess>
-#include <KProgressDialog>
 
 class KProcess;
+class KProgressDialog;
 
-
-class ProcessProgress : public QWidget
+class ProcessProgress : public QObject
 {
 Q_OBJECT
 
-    bool m_show_progress;
     QEventLoop *m_loop;
     QStringList m_output_all, m_output_no_error;
-    KProgressDialog *m_progress_dialog;
     KProcess *m_process;
+    KProgressDialog *m_progress_dialog;
+    int m_exit_code;
 
  public:
-    ProcessProgress(QStringList arguments,
-		    QString operation, 
-		    bool showProgress = false, 
-		    QWidget *parent = 0);
+    ProcessProgress(QStringList arguments, const bool allowCancel = false, QObject *parent = NULL);
 
     QStringList programOutput();
     QStringList programOutputAll();
     int exitCode();
     
- public slots:   
-     void stopProgressLoop(int exitCode, QProcess::ExitStatus);
-     void readStandardOut();
-     void readStandardError();
+ private slots:   
+    void cleanup(const int code, const QProcess::ExitStatus status);
+    void cancelProcess();
+    void readStandardOut();
+    void readStandardError();
  
 };
 
