@@ -1,7 +1,7 @@
 /*
  *
  * 
- * Copyright (C) 2008 Benjamin Scott   <benscott@nwlink.com>
+ * Copyright (C) 2008, 2011 Benjamin Scott   <benscott@nwlink.com>
  *
  * This file is part of the Kvpm project.
  *
@@ -15,21 +15,34 @@
 #ifndef PVCHANGE_H
 #define PVCHANGE_H
 
+#include <KComboBox>
 #include <KDialog>
+#include <KLineEdit>
 #include <QCheckBox>
+#include <QGroupBox>
 #include <QLabel>
 #include <QStringList>
 
+class PhysVol;
+
 class PVChangeDialog : public KDialog
 {
 Q_OBJECT
 
-     QCheckBox *allocation_box;
-     QString m_pv_path;
+     KLineEdit *m_tag_edit;      // new tag to add 
+     KComboBox *m_deltag_combo;  // old tag to remove
+     QGroupBox *m_tags_group;
+     QCheckBox *m_allocation_box;
+     QCheckBox *m_uuid_box;
+     QCheckBox *m_mda_box;
+     PhysVol   *m_pv;
 
 public:
-     PVChangeDialog(QString physicalVolumePath, QWidget *parent = 0);
+     explicit PVChangeDialog(PhysVol *physicalVolume, QWidget *parent = 0);
      QStringList arguments();
+
+private slots:
+     void resetOkButton();
  
 };
 
