@@ -1,7 +1,7 @@
 /*
  *
  * 
- * Copyright (C) 2008 Benjamin Scott   <benscott@nwlink.com>
+ * Copyright (C) 2008, 2010, 2011 Benjamin Scott   <benscott@nwlink.com>
  *
  * This file is part of the Kvpm project.
  *
@@ -16,15 +16,22 @@
 #define PVPROPERTIES_H
 
 
-#include <QTableWidget>
+#include <QFrame>
 
+class LVSegmentExtent;
 class PhysVol;
 
-class PVProperties : public QTableWidget
+class PVProperties : public QWidget
 {
+    PhysVol *m_pv;
+
+    QList<LVSegmentExtent *> sortByExtent();
+    QFrame *buildMdaBox();
+    QFrame *buildLvBox();
+    QFrame *buildUuidBox();
 
  public:
-    PVProperties(PhysVol *physicalVolume, QWidget *parent = 0);
+    explicit PVProperties(PhysVol *const volume, QWidget *parent = 0);
 
 };
 
