@@ -1,7 +1,7 @@
 /*
  *
  * 
- * Copyright (C) 2008 Benjamin Scott   <benscott@nwlink.com>
+ * Copyright (C) 2008, 2010, 2011 Benjamin Scott   <benscott@nwlink.com>
  *
  * This file is part of the Kvpm project.
  *
@@ -15,21 +15,31 @@
 #ifndef PVPROPERTIESSTACK_H
 #define PVPROPERTIESSTACK_H
 
-#include <QStackedWidget>
-#include <QTreeWidget>
+#include <QFrame>
+#include <QLabel>
 #include <QList>
+#include <QStackedWidget>
+#include <QTreeWidgetItem>
+#include <QScrollArea>
+
  
 class PhysVol;
+class VolGroup;
 
-class PVPropertiesStack : public QStackedWidget
+class PVPropertiesStack : public QFrame
 {
 Q_OBJECT
+
+    QStackedWidget *m_stack_widget;
     bool m_is_pv;
     VolGroup *m_vg;
     QList<QStackedWidget *> m_pv_stack_list;
-    
+    QLabel *m_pv_label;       // The name of the device
+    QScrollArea *m_vscroll;    
+
  public:
-    PVPropertiesStack(VolGroup *volumeGroup, QWidget *parent = 0);
+    explicit PVPropertiesStack(VolGroup *volumeGroup, QWidget *parent = 0);
+    void loadData();
  
  public slots:
     void changePVStackIndex(QTreeWidgetItem *item, QTreeWidgetItem*);
