@@ -1,7 +1,7 @@
 /*
  *
  * 
- * Copyright (C) 2009 Benjamin Scott   <benscott@nwlink.com>
+ * Copyright (C) 2009, 2011 Benjamin Scott   <benscott@nwlink.com>
  *
  * This file is part of the kvpm project.
  *
@@ -15,11 +15,8 @@
 #ifndef REMOVEFS_H
 #define REMOVEFS_H
 
+#include "QString" 
 
-#include <QString>
-
-#include "storagepartition.h"
-
-bool remove_fs(StoragePartition *partition);
+bool remove_fs(const QString name);
 
 #endif
