@@ -1,7 +1,7 @@
 /*
  *
  * 
- * Copyright (C) 2008 Benjamin Scott   <benscott@nwlink.com>
+ * Copyright (C) 2008, 2011 Benjamin Scott   <benscott@nwlink.com>
  *
  * This file is part of the Kvpm project.
  *
@@ -20,27 +20,29 @@
 #include <QList>
 
 class LogVol;
+class MountEntry;
 class NoMungeCheck;
 class StoragePartition;
 
-bool unmount_filesystem(StoragePartition *partition);
-bool unmount_filesystem(LogVol *logicalVolume);
-bool unmount_filesystem(const QString mountPoint);
-
 
 class UnmountDialog : public KDialog
 {
 Q_OBJECT
 
+    bool m_bailout;
+    bool m_single;
+    QString m_mp;
     QList<NoMungeCheck *> m_check_list; // one check box for each mount point
-    QStringList m_mount_points;
  
  public:
-    UnmountDialog(QString device, QStringList mountPoints, 
-		  QList<int> mountPosition, QWidget *parent = 0);
+    UnmountDialog(StoragePartition *const partition, QWidget *parent = NULL);
+    UnmountDialog(LogVol *const volume, QWidget *parent = NULL);
+    void buildDialog(QString const device, const QList<MountEntry *> entries);
+    bool bailout();
 
  private slots:   
-    void unmountFilesystems();
+    void resetOkButton();
+    void commitChanges();
  
 };
 
