@@ -1,7 +1,7 @@
 /*
  *
  * 
- * Copyright (C) 2008 Benjamin Scott   <benscott@nwlink.com>
+ * Copyright (C) 2008, 2011, 2012 Benjamin Scott   <benscott@nwlink.com>
  *
  * This file is part of the Kvpm project.
  *
@@ -15,28 +15,32 @@
 #ifndef VGCREATE_H
 #define VGCREATE_H
 
+#include <KComboBox>
 #include <KDialog>
 #include <KLineEdit>
-#include <KComboBox>
 
+#include <QLabel>
 #include <QStringList>
 #include <QCheckBox>
 #include <QRegExpValidator>
+#include <QVBoxLayout>
 
-#include "nomungecheck.h"
-
-
-bool create_vg(QString physicalVolumePath);
-
-bool create_vg();
+class StorageDevice;
+class StoragePartition;
+class PvGroupBox;
 
 
 class VGCreateDialog : public KDialog
 {
 Q_OBJECT
 
-    QStringList  m_pv_paths;
-    QList<NoMungeCheck *> m_pv_checks;
+    bool m_bailout;
+
+    QLabel *m_pv_label, 
+           *m_total_available_label, 
+           *m_total_selected_label;
+
+    PvGroupBox  *m_pv_checkbox;
 
     KLineEdit *m_vg_name, 
               *m_max_lvs, 
@@ -51,16 +55,23 @@ Q_OBJECT
               *m_extent_suffix;
 
     QRegExpValidator *m_validator;
+
+    void buildDialog(QList<StorageDevice *> devices, QList<StoragePartition *> partitions);
+    void getUsablePvs(QList<StorageDevice *> &devices, QList<StoragePartition *> &partitions);
+    void limitExtentSize(int);
     
  public:
-    VGCreateDialog(QStringList physicalVolumePathList, QWidget *parent = 0);
-    QStringList arguments();
-    
+    explicit VGCreateDialog(QWidget *parent = NULL);
+    VGCreateDialog(StorageDevice *const device, StoragePartition *const partition, QWidget *parent = NULL);
+    bool bailout();    
+
  private slots:
-    void limitLogicalVolumes(int boxstate);
-    void limitPhysicalVolumes(int boxstate);
+    //void limitLogicalVolumes(int boxstate);
+    //void limitPhysicalVolumes(int boxstate);
     void validateOK();
-    
+    void commitChanges();
+    void extentSizeChanged();
+
 };
 
 #endif
