@@ -1,7 +1,7 @@
 /*
  *
  * 
- * Copyright (C) 2008 Benjamin Scott   <benscott@nwlink.com>
+ * Copyright (C) 2008, 2011 Benjamin Scott   <benscott@nwlink.com>
  *
  * This file is part of the kvpm project.
  *
@@ -13,29 +13,29 @@
  */
 
 
+#include "vgimport.h"
+
 #include <KMessageBox>
 #include <KLocale>
+
 #include <QtGui>
 
 #include "logvol.h"
 #include "processprogress.h"
-#include "vgimport.h"
 #include "volgroup.h"
 
 
-bool import_vg(VolGroup *volumeGroup)
+bool import_vg(VolGroup *const volumeGroup)
 {
-
     QStringList args;
-
-    QString message = i18n("Import volume group: %1 ?").arg(volumeGroup->getName());
+    const QString message = i18n("Import volume group: <b>%1</b>?", volumeGroup->getName());
     
-    if(KMessageBox::questionYesNo( 0, message) == 3){      // 3 = "yes" button
+    if(KMessageBox::questionYesNo( 0, message) == KMessageBox::Yes){
 
 	args << "vgimport"
 	     << volumeGroup->getName();
 	
-	ProcessProgress remove(args, i18n("Importing volume group..."), true);
+	ProcessProgress remove(args);
 	return true;
     }
     else{
