@@ -1,7 +1,7 @@
 /*
  *
  * 
- * Copyright (C) 2008 Benjamin Scott   <benscott@nwlink.com>
+ * Copyright (C) 2008, 2011 Benjamin Scott   <benscott@nwlink.com>
  *
  * This file is part of the Kvpm project.
  *
@@ -12,13 +12,13 @@
  * See the file "COPYING" for the exact licensing terms.
  */
 
-#ifndef VGEXPORT_H
-#define VGEXPORT_H
+#ifndef VGIMPORT_H
+#define VGIMPORT_H
 
 
 class VolGroup;
 
-bool export_vg(VolGroup *volumeGroup);
+bool export_vg(VolGroup *const volumeGroup);
 
 
 #endif
