@@ -1,7 +1,7 @@
 /*
  *
  * 
- * Copyright (C) 2008 Benjamin Scott   <benscott@nwlink.com>
+ * Copyright (C) 2008, 2010, 2011, 2012 Benjamin Scott   <benscott@nwlink.com>
  *
  * This file is part of the Kvpm project.
  *
@@ -16,12 +16,13 @@
 #define VGREDUCE_H
 
 #include <KDialog>
+
 #include <QCheckBox>
 #include <QStringList>
 
 
 class VolGroup;
-class NoMungeCheck;
+class PvGroupBox;
 
 bool reduce_vg(VolGroup *volumeGroup);
 
@@ -30,17 +31,17 @@ class VGReduceDialog : public KDialog
 {
 Q_OBJECT
 
-    QString m_vg_name;
-    QList<NoMungeCheck *> m_pv_check_boxes;
+    VolGroup *m_vg;
+    PvGroupBox *m_pv_checkbox; 
     bool m_unremovable_pvs_present;
-    
+
  public:
-    VGReduceDialog(VolGroup *volumeGroup, QWidget *parent = 0);
+    explicit VGReduceDialog(VolGroup *const volumeGroup, QWidget *parent = NULL);
     QStringList arguments();
     
  private slots:
-    void excludeOneVolume(bool);  // one pv must remain in the vg
- 
+    void excludeOneVolume();  // one pv must remain in the vg
+    void commitChanges();
 };
 
 #endif
