@@ -1,7 +1,7 @@
 /*
  *
  * 
- * Copyright (C) 2008 Benjamin Scott   <benscott@nwlink.com>
+ * Copyright (C) 2008, 2011 Benjamin Scott   <benscott@nwlink.com>
  *
  * This file is part of the Kvpm project.
  *
@@ -13,32 +13,28 @@
  */
 
 
+#include "vgreduceone.h"
+
 #include <KMessageBox>
 #include <KLocale>
 #include <QtGui>
 
-#include "vgreduceone.h"
 #include "processprogress.h"
 
 
 bool reduce_vg_one(QString volumeGroupName, QString physicalVolumeName)
 {
-
     QStringList args;
- 
-    QString message = i18n("Remove physical volume: <b>%1</b> from volume " 
-			   "group: <b>%2</b>").arg(physicalVolumeName).arg(volumeGroupName);
-    
+    const QString message = i18n( "Remove physical volume: <b>%1</b> from volume " 
+                                  "group: <b>%2</b>", physicalVolumeName, volumeGroupName );
 
-    int return_code =  KMessageBox::questionYesNo( 0, message);
-
-    if(return_code == 3){  // 3 = yes button
+    if(KMessageBox::questionYesNo(0, message) == KMessageBox::Yes){
 
 	args << "vgreduce"
 	     << volumeGroupName
 	     << physicalVolumeName;
 
-	ProcessProgress remove( args, i18n("Reducing vg..."), true );
+	ProcessProgress remove(args);
 
 	return true;
     }
