@@ -1,7 +1,7 @@
 /*
  *
  * 
- * Copyright (C) 2008 Benjamin Scott   <benscott@nwlink.com>
+ * Copyright (C) 2008, 2011 Benjamin Scott   <benscott@nwlink.com>
  *
  * This file is part of the Kvpm project.
  *
@@ -12,13 +12,14 @@
  * See the file "COPYING" for the exact licensing terms.
  */
 
-#ifndef VGNAME_H
-#define VGNAME_H
+#ifndef VGRENAME_H
+#define VGRENAME_H
 
 #include <KDialog>
 #include <KLineEdit>
 
 #include <QStringList>
+#include <QRegExpValidator>
 
 class VolGroup;
 
@@ -33,8 +34,10 @@ Q_OBJECT
     QRegExpValidator *m_name_validator;
 
 public:
-    VGRenameDialog(VolGroup *volumeGroup, QWidget *parent = 0);
+    explicit VGRenameDialog(VolGroup *volumeGroup, QWidget *parent = 0);
     QStringList arguments();
+    QString getNewName();
+    QString getOldName();
 
 private slots:
     void validateName(QString);
